@@ -1,7 +1,7 @@
-__version__ = "0.9"
-__version_info__ = ['0', '9']
+__version__ = "0.9.1"
+__version_info__ = ['0', '9', '1']
 __version_vcs_info__ = {'branch': 'master',
- 'revid': 'c522b8e',
- 'revno': 1505,
+ 'revid': '715e737',
+ 'revno': 1511,
  'toplevel': '/home/saxtouri/src/kamaki/kamaki'}
 __version_user_info__ = "saxtouri@terminus"
